<?php
require_once('widgets/class-wp-widget-categories.php');
require_once('widgets/class-wp-widget-recent-posts.php');
require_once('widgets/class-wp-widget-archives.php');

/**
 * Sets up theme defaults and registers support for various WordPress features.
 */
function jasper_setup(){
	load_theme_textdomain( 'jasper', get_template_directory() . '/languages' );
	
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	
	//Featured Image Support
	add_theme_support('post-thumbnails');
	
	//Nav Menus
	register_nav_menus(array(
		'menu-1' => __('Primary Menu', 'jasper')
	));
	
	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'audio',
	) );
	
	/*
	 * Enable custom image header.
	 */
	add_theme_support( 'custom-header', array(
        'default-image'      => get_template_directory_uri() . '/assets/images/banner1.jpg',
        'default-text-color' => '000',
        'width'              => 1350,
        'height'             => 700,
        'flex-width'         => true,
        'flex-height'        => true,
	) );
	
	add_theme_support( 'title-tag' );
}
add_action('after_setup_theme', 'jasper_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function nat_s1_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'nat_s1_content_width', 640 );
}
add_action( 'after_setup_theme', 'nat_s1_content_width', 0 );

/** Excerpt Length */
function set_excerpt_length(){
	return 20;
}

add_filter('excerpt_length', 'set_excerpt_length');

// Widget Locations
function init_widgets($id){
	register_sidebar(array(
		'name'	=> 'Sidebar',
		'id'	=> 'sidebar',
		'before_widget'	=> '<div class="widget">',
		'after_widget'	=> '</div>',
		'before_title'	=> '<h2 class="widget-title">',
		'after_title'	=> '</h2>'
	));
	register_sidebar(array(
		'name'	=> 'Footer',
		'id'	=> 'footer',
		'before_widget'	=> '<div>',
		'after_widget'	=> '</div>',
		'before_title'	=> '<h2 style="display: none;">',
		'after_title'	=> '</h2>'
	));
}

add_action('widgets_init', 'init_widgets');

/* Adds 'list-group-item' to categories li
function add_new_class_list_categories($list){
	$list = str_replace('cat-item', 'cat-item list-group-item', $list);
	return $list;
}

add_filter('wp_list_categories', 'add_new_class_list_categories');
*/

// Register Widgets
function jasper_register_widgets(){
	register_widget('WP_Widget_Categories_Custom');
	register_widget('WP_Widget_Recent_Posts_Custom');
	register_widget('WP_Widget_Archives_Custom');
}

add_action('widgets_init', 'jasper_register_widgets');

/**
 * Enqueue scripts and styles.
 */
function jasper_scripts() {
	wp_enqueue_style( 'theme_style-style', get_stylesheet_uri() );
	wp_enqueue_style( 'theme_style-bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css', array(), '3.3.5' );
	wp_enqueue_style( 'theme_style-custom', get_template_directory_uri() . '/assets/css/custom.css', array(), null );
	wp_enqueue_style( 'theme_style-font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css', array(), '4.4.0' );

	wp_enqueue_script( 'theme_script-jquery', get_template_directory_uri() . '/assets/js/jquery-1.11.3.js', array(), '1.11.3', true );
	wp_enqueue_script( 'theme_script-bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js', array(), '3.3.5', true );
	wp_enqueue_script( 'theme_script-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), null, true );
	wp_enqueue_script( 'theme_script-scripts', get_template_directory_uri() . '/assets/js/scripts.js', array(), null, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'jasper_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';
